package de.javabeginners.plugin.notice.ui.elements;

import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.CTabFolder;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;

/**
 * A composite with buttons on the right to handle the views content and a main
 * area on the left to display various input elements.
 * 
 * @author Joerg Czeschla, javabeginners.de
 * 
 *
 */
public class ButtonComposite extends Composite {

	private static final String ADD_LABEL = "Add";
	private static final String DELETE_LABEL = "Delete";
	private static final String CLEAR_LABEL = "Clear";

	private Composite viewArea;
	NoticeButtonManager buttonManager;

	public ButtonComposite(CTabFolder parent, int style) {
		super(parent, style);
		setupUI(parent);
	}

	/**
	 * Create the UI
	 * @param parent <code>Composite</code>, the <code>CTabFolder</code> object.
	 */
	private void setupUI(Composite parent) {
		this.setLayout(new GridLayout(2, false));
		GridData gridData = new GridData(SWT.FILL, SWT.FILL, true, true);
		gridData.widthHint = GridData.FILL_HORIZONTAL;
		gridData.heightHint = GridData.FILL_VERTICAL;
		this.setLayoutData(gridData);
		createViewArea(this);
		createButtonsArea(this);
	}

	private void createViewArea(final Composite parent) {
		viewArea = new Composite(parent, SWT.BORDER);
		GridLayout gridLayout = new GridLayout(1, true);
		viewArea.setLayout(gridLayout);
		GridData gridData = new GridData(SWT.FILL, SWT.FILL, true, true);
		gridData.widthHint = GridData.FILL_HORIZONTAL;
		gridData.heightHint = GridData.FILL_VERTICAL;
		viewArea.setLayoutData(gridData);
	}

	private void createButtonsArea(final Composite parent) {
		Composite buttArea = new Composite(parent, SWT.BORDER);
		GridLayout buttAreaLayout = new GridLayout(1, true);
		buttAreaLayout.marginWidth = 0;
		buttAreaLayout.marginHeight = 0;
		buttAreaLayout.verticalSpacing = 8;
		buttAreaLayout.horizontalSpacing = 0;
		buttArea.setLayout(buttAreaLayout);
		GridData buttAreaData = new GridData(SWT.FILL, SWT.FILL, false, true);
		buttAreaData.widthHint = 50;
		buttAreaData.heightHint = GridData.FILL_VERTICAL;
		buttArea.setLayoutData(buttAreaData);

		// Add button
		Button add = new Button(buttArea, SWT.PUSH | SWT.FLAT);
		add.setLayoutData(new GridData(SWT.FILL, SWT.DEFAULT, false, false));
		add.setText(ADD_LABEL);
		add.addSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent e) {
				buttonManager.add();
			}
		});

		// Delete button
		Button delete = new Button(buttArea, SWT.PUSH | SWT.FLAT);
		delete.setLayoutData(new GridData(SWT.FILL, SWT.DEFAULT, false, false));
		delete.setText(DELETE_LABEL);
		delete.addSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent e) {
				buttonManager.delete();
			}
		});

		// Clear button
		Button clear = new Button(buttArea, SWT.PUSH | SWT.FLAT);
		clear.setLayoutData(new GridData(SWT.FILL, SWT.DEFAULT, false, false));
		clear.setText(CLEAR_LABEL);
		clear.addSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent e) {
				buttonManager.clear();
			}
		});
	}

	public Composite getViewArea() {
		return viewArea;
	}

	/**
	 * Sets the view widget to occupy the main layout space.
	 * 
	 * @param comp <code>NoticeComposite</code>
	 */
	public void setViewer(NoticeComposite comp) {
		this.buttonManager = (NoticeButtonManager) comp;
	}
}
