package de.javabeginners.plugin.notice.ui.elements;

import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.jface.dialogs.IInputValidator;
import org.eclipse.jface.dialogs.IMessageProvider;
import org.eclipse.jface.dialogs.TitleAreaDialog;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;

/**
 * Dynamic Dialog to receive a new set of data for a table view. The dialog
 * displays a variable number of textfields according to the number of columns
 * in the table. Each textfield receives a String which will be shown in one
 * column.
 * 
 * @author Joerg Czeschla, javabeginners.de
 * 
 *
 */
public class NewTableDataInputDialog extends TitleAreaDialog {

	private String title;
	private int colCount;
	private Text[] colField;
	String[] values;

	public NewTableDataInputDialog(Shell parentShell, String title,
			String initialValue, IInputValidator validator,
			int cols) {
		super(parentShell);
		this.title = title;
		this.colCount = cols;
	}
	
	@Override
	public void create() {
		super.create();
		setTitle(title);
		setMessage("Insert new table values",
				IMessageProvider.INFORMATION);
	}

	@Override
	protected boolean isResizable() {
		return true;
	}

	@Override
	protected Control createDialogArea(Composite parent) {
		Composite area = (Composite) super.createDialogArea(parent);
		Composite container = new Composite(area, SWT.NONE);
		container.setLayoutData(new GridData(GridData.FILL_BOTH));
		GridLayout gridLayout = new GridLayout(2, false);
		container.setLayout(gridLayout);
		// rows
		GridData rowLabelData, rowFieldData;
		Label colLabel;
		colField = new Text[colCount];
		for (int i = 0; i < colCount; i++) {
			rowLabelData = new GridData();
			rowLabelData.grabExcessHorizontalSpace = false;
			rowLabelData.horizontalAlignment = GridData.FILL;
			rowLabelData.horizontalSpan = 1;

			colLabel = new Label(container, SWT.NONE);
			colLabel.setText("Column " + (i + 1));
			colLabel.setLayoutData(rowLabelData);

			rowFieldData = new GridData();
			rowFieldData.grabExcessHorizontalSpace = true;
			rowFieldData.horizontalAlignment = GridData.FILL;
			rowFieldData.horizontalSpan = 1;

			colField[i] = new Text(container, SWT.BORDER);
			colField[i].setLayoutData(rowFieldData);
		}
		return container;
	}

	@Override
	protected void configureShell(Shell newShell) {
		super.configureShell(newShell);
		newShell.setText(title);
	}

	public String[] getValues() {
		return values;
	}

	@Override
	protected void buttonPressed(int buttonId) {
		if (buttonId == IDialogConstants.OK_ID) {
			values = new String[colField.length];
			for (int i = 0; i < colField.length; i++) {
				values[i] = colField[i].getText();
			}
		} else {
			values = null;
		}
		super.buttonPressed(buttonId);
	}
}
