package de.javabeginners.plugin.notice.ui.elements;

import org.eclipse.jface.dialogs.IDialogSettings;
import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.CTabFolder;

/**
 * Creates the different composites (tab types) of the view.
 * 
 * @author Joerg Czeschla, javabeginners.de
 * 
 *
 */
public class NoticeCompositeFactory {

	private CTabFolder tabFolder;
	private String id;
	private IDialogSettings settings;

	public NoticeCompositeFactory(CTabFolder tabFolder, String id,
			IDialogSettings settings) {
		this.tabFolder = tabFolder;
		this.id = id;
		this.settings = settings;
	}

	/**
	 * Creates the view type (text, list, table) depending on
	 * <code>viewType</code>.
	 * 
	 * @param viewType
	 *            <code>String</code> The type of button-composite. Possible
	 *            values are: <code>Text</code>, <code>Liste</code>,
	 *            <code>Tabelle</code>.
	 * 
	 * @return <code>NoticeComposite</code>, the composite depending on the
	 *         choosen <code>viewType</code>. The types Liste and Tabelle
	 *         contain an additional button bar, which is used to add or delete
	 *         entries.
	 * 
	 */
	public NoticeComposite getNoticeComposite(String viewType) {
		// build chosen view widget and set
		NoticeComposite viewer;
		int style = SWT.NONE; // set to SWT.BORDER to display a border
		ButtonComposite btnComp;

		switch (viewType) {
		case "Text":
			viewer = new NoticeText("dummy title", id, tabFolder, settings,
					style);
			break;
		case "Liste":
			btnComp = new ButtonComposite(tabFolder, SWT.NONE);
			viewer = new NoticeList(id, btnComp.getViewArea(), btnComp,
					settings, style);
			btnComp.setViewer(viewer);
			break;
		case "Tabelle":
			btnComp = new ButtonComposite(tabFolder, SWT.NONE);
			viewer = new NoticeTable(id, btnComp.getViewArea(), btnComp,
					settings, style);
			btnComp.setViewer(viewer);
			break;
		default:
			viewer = null;
		}

		return viewer;
	}
}
