package de.javabeginners.plugin.notice.ui.elements;

import java.util.ArrayList;

import org.eclipse.jface.dialogs.IDialogSettings;
import org.eclipse.jface.viewers.CellEditor;
import org.eclipse.jface.viewers.ColumnLabelProvider;
import org.eclipse.jface.viewers.ColumnViewer;
import org.eclipse.jface.viewers.EditingSupport;
import org.eclipse.jface.viewers.ISelectionProvider;
import org.eclipse.jface.viewers.TableViewer;
import org.eclipse.jface.viewers.TableViewerColumn;
import org.eclipse.jface.viewers.TextCellEditor;
import org.eclipse.jface.window.Window;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Table;

import de.javabeginners.plugin.notice.ui.views.NoticeView;

/**
 * Tabellen-View component representing a plugin's table tab.
 * 
 * @author Joerg Czeschla, javabeginners.de
 *
 */
public class NoticeTable extends NoticeComposite implements NoticeButtonManager {

	private final String id;
	private ButtonComposite buttComp;
	private TableViewer viewer;
	private IDialogSettings settings;
	private TableContentProvider tcp;
	public static final String DEFAULT_COLCOUNT = "2";
	private int colCount;

	public NoticeTable(String id, Composite parent, ButtonComposite buttComp,
			IDialogSettings settings, int style) {
		super(parent, id, style);

		this.id = id;
		this.buttComp = buttComp;
		this.settings = settings;
		IDialogSettings colCountSettings = settings.getSection(NoticeView.COLCOUNT_SETTINGS);
		String ccs = colCountSettings.get(id);
		this.colCount = new Integer(ccs).intValue();
		this.setupUI();
	}

	private void setupUI() {
		// setup the viewer
		this.viewer = new TableViewer(this, SWT.MULTI | SWT.H_SCROLL
				| SWT.V_SCROLL);
		final Table table = viewer.getTable();
		GridData viewerData = new GridData(GridData.FILL_BOTH);
		table.setLayoutData(viewerData);
		tcp = new TableContentProvider(id, settings);
		viewer.setContentProvider(tcp);
		table.setHeaderVisible(true);
		table.setLinesVisible(true);

		TableViewerColumn[] cols = new TableViewerColumn[colCount];
		for (int i = 0; i < colCount; i++) {
			cols[i] = new TableViewerColumn(viewer, SWT.NONE);
			cols[i].getColumn().setWidth(200);
			cols[i].getColumn().setText("Spalte " + (i + 1));
			cols[i].getColumn().setResizable(true);
			cols[i].setLabelProvider(new TableColumnLabelProvider(i));
			cols[i].setEditingSupport(new NoticeTableEditingSupport(viewer, i));
		}

		// has to be set after the columns had been defined
		viewer.setInput(tcp.getObjects());
	}

	@Override
	public Control getControl() {
		return this.buttComp;
	}

	@Override
	public Object getContents() {
		ArrayList<TableElement> cont = (ArrayList<TableElement>) tcp
				.getObjects();
		String[][] str = new String[cont.size()][colCount];
		for (int i = 0; i < cont.size(); i++) {
			for (int j = 0; j < colCount; j++) {
				str[i][j] = ((TableElement) cont.get(i)).getTableElements()[j];
			}

		}
		return str;
	}

	@Override
	public void setContents(Object obj) {
	}

	@Override
	public ISelectionProvider getSelectionProvider() {
		return null;
	}

	/**
	 * Deletes a selected table row
	 */
	public void delete() {
		Object o = viewer.getSelection();
		if (o == null)
			return;
		tcp.removeElement(o);
		viewer.refresh();
	}

	/**
	 * Clears the table
	 */
	public void clear() {
		tcp.clear();
		viewer.setInput(null);
		viewer.refresh();
	}

	/**
	 * Adds a row to the table
	 */
	public void add() {
		TableElement te = new TableElement(colCount);
		String[] strs;
		NewTableDataInputDialog inputDialog = new NewTableDataInputDialog(
				getShell(), "New Table Values",
				"", null, colCount);
		if (inputDialog.open() != Window.OK) {
			return;
		}
		strs = inputDialog.getValues();
		if (strs == null)
			return;
		te.setElements(strs);
		tcp.addElement(te);
		viewer.setInput(tcp.getObjects());
		viewer.refresh();
	}

	public String getID() {
		return id;
	}

	private class NoticeTableEditingSupport extends EditingSupport {

		private int col;

		public NoticeTableEditingSupport(ColumnViewer viewer, int col) {
			super(viewer);
			this.col = col;
		}

		@Override
		protected CellEditor getCellEditor(Object element) {
			return new TextCellEditor((Composite) getViewer().getControl());
		}

		@Override
		protected boolean canEdit(Object element) {
			return true;
		}

		@Override
		protected Object getValue(Object element) {
			TableElement te = (TableElement) element;
			return te.getElement(col);
		}

		@Override
		protected void setValue(Object element, Object value) {
			TableElement te = (TableElement) element;
			String s = (String) value;
			te.setElement(s, col);
			viewer.setInput(tcp.getObjects());
			viewer.refresh();
		}
	}

	private class TableColumnLabelProvider extends ColumnLabelProvider {
		int col;

		private TableColumnLabelProvider(int col) {
			super();
			this.col = col;
		}

		public String getText(Object element) {
			TableElement te = (TableElement) element;
			return te.getElement(col);
		}
	}
}
