package de.javabeginners.plugin.notice.ui.elements;

import org.eclipse.jface.dialogs.IDialogSettings;
import org.eclipse.jface.text.Document;
import org.eclipse.jface.text.TextViewer;
import org.eclipse.jface.viewers.ISelectionProvider;
import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.CTabFolder;
import org.eclipse.swt.custom.StyledText;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.widgets.Control;

/**
 * Text-View-Komponente zur Darstellung in einem Tab
 * 
 * @author Joerg Czeschla, javabeginners.de
 *
 */
public class NoticeText extends NoticeComposite {

	private String contentText = "";
	private IDialogSettings settings;
	private Document doc;
	private TextViewer viewer;
	private final String id;

	public NoticeText(String title, String id, CTabFolder tabFolder,
			IDialogSettings settings, int style) {
		super(tabFolder, id, style);
		viewer = new TextViewer(tabFolder, SWT.H_SCROLL | SWT.V_SCROLL);
		this.id = id;
		this.settings = settings;
		((StyledText) viewer.getControl())
				.addModifyListener(new NoticeModifyListener());
		contentText = settings.get(id);
		doc = new Document();
		viewer.setDocument(doc);
		setContents(contentText);
	}

	@Override
	public Object getContents() {
		return (Object) doc.get();
	}

	@Override
	public void setContents(Object obj) {
		if (obj instanceof String)
			doc.set((String) obj);
	}

	@Override
	public Control getControl() {
		return viewer.getControl();
	}

//	public void setControl(Control control) {
//		 viewer.setContorl(control);
//	}

	@Override
	public ISelectionProvider getSelectionProvider() {
		return viewer.getSelectionProvider();
	}
	
	public String getID() {
		return id;
	}

	class NoticeModifyListener implements ModifyListener {
		@Override
		public void modifyText(ModifyEvent e) {
			StyledText txt = (StyledText) e.widget;
			contentText = txt.getText();
			settings.put(id, contentText);
		}
	}
}
