package de.javabeginners.plugin.notice.ui.elements;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.HashSet;

import org.eclipse.jface.dialogs.IDialogSettings;
import org.eclipse.jface.viewers.IStructuredContentProvider;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.Viewer;

public class TableContentProvider implements IStructuredContentProvider {
	IDialogSettings settings;
	// ID des Tabs
	String id;
	/**
	 * <p>
	 * <code>ArrayList</code> mit den String-Arrays der Tabelleneintr&auml;ge.<br>
	 * Die Eintr&auml;ge jeder Tabellenzeile werden in einem String-Array
	 * gespeichert, dem jeweils eine ID zugewiesen ist. Die einzelnen Arrays
	 * sind mit ihrerer ID als Key in {@link #settings} gespeichert.
	 * </p>
	 * <p>
	 * Die IDs der einzelnen Zeilen-Arrays sind in der <code>ArrayList</code>
	 * {@link #objIds} abgelegt. Diese <code>ArrayList</code> ist mit der ID des
	 * Tabs in {@link #settings} abgelegt.
	 */
	ArrayList<TableElement> objects;
	/**
	 * ArrayList mit den IDs der String-Arrays der Tabellenzeilen. @see
	 * {@link #objects}
	 */
	// ArrayList<String> objIds;
	HashSet<String> objIds;

	public TableContentProvider(String id, IDialogSettings settings) {
		System.out.println("Create ContentProvider for table '" + id + "'");
		this.id = id;
		this.settings = settings;
		// list of String[]; one of each table row
		this.objects = new ArrayList<TableElement>();
		// get the list with the ids of the entries
		String[] str = settings.getArray(id);
		if (str != null) {
			objIds = new HashSet<String>(Arrays.asList(str));
		} else {
			objIds = new HashSet<String>();
		}
	}

	/**
	 * Called when adding new elements
	 * 
	 * @param obj
	 *            <code>TableElement</code>
	 */
	public void addElement(Object obj) {
		TableElement elem = (TableElement) obj;
		objects.add(elem);
	}

	public void clear() {
		objects.clear();
		objIds.clear();
		save();
	}

	public void removeElement(Object obj) {
		TableElement te = (TableElement) ((IStructuredSelection) obj)
				.getFirstElement();
		if (te == null)
			return;
		objects.remove(te);
		objIds.remove(te.getID());
	}

	public void removeElements() {
		objects.clear();
	}

	@Override
	public Object[] getElements(Object obj) {
		if (obj instanceof Object[]) {
			return (Object[]) obj;
		}
		if (obj instanceof Collection) {
			return ((Collection<?>) obj).toArray();
		}
		return new Object[0];
	}

	@Override
	public void dispose() {
		save();
	}

	private void save() {
		if (objects == null)
			return;
		String singleID;
		for (TableElement s : objects) {
			if (s == null)
				continue;
			// ID of one table row
			singleID = s.getID();
			settings.put(singleID, s.getTableElements());
			if (!objIds.contains(singleID))
				objIds.add(singleID);
		}
		String[] arrStr = new String[objIds.size()];
		arrStr = (String[]) objIds.toArray(arrStr);
		settings.put(id, arrStr);
	}

	public void replace(Viewer viewer, Object oldValue, Object newValue) {
		viewer.refresh();
	}

	@Override
	public void inputChanged(Viewer viewer, Object oldInput, Object newInput) {
	}

	public Collection<TableElement> getObjects() {
		if (objects == null || objects.size() == 0) {
			// IDs auslesen
			String[] idArr = settings.getArray(id);
			if (idArr == null) {
				objects = new ArrayList<TableElement>();
				return objects;
			}
			// IDs durchlaufen und zugehörige Arrays ermitteln
			for (String s : idArr) {
				String[] teValue = settings.getArray(s);
				TableElement te = new TableElement(s, teValue);
				objects.add(te);
			}
		}
		return objects;
	}
}
