package de.javabeginners.plugin.notice.ui.elements;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.util.UUID;

/**
 * The class is used to store <code>String</code> values. Each object stores a
 * particular set of <code>String</code> elements in an array and provides an id
 * to identify the object stored in the plugin's settings.
 * 
 * @author Joerg Czeschla, javabeginners.de
 * 
 *
 */
public class TableElement {
	/**
	 * The elements to be stored in the plugin's table representation
	 */
	private String[] elements;
	/**
	 * Random ID which is used to identify the <code>TableElement</code> object
	 * stored in the plugin's settings.
	 */
	private String id;

	private PropertyChangeSupport propertyChangeSupport = new PropertyChangeSupport(
			this);

	public TableElement(int cols) {
		this(UUID.randomUUID().toString(), new String[cols]);
	}

	public TableElement(String[] elements) {
		this(UUID.randomUUID().toString(), elements);
	}

	public TableElement(String id, String[] elements) {
		this.id = id;
		this.elements = elements;
	}

	public void addPropertyChangeListener(String propertyName,
			PropertyChangeListener listener) {
		propertyChangeSupport.addPropertyChangeListener(propertyName, listener);
	}

	public void removePropertyChangeListener(PropertyChangeListener listener) {
		propertyChangeSupport.removePropertyChangeListener(listener);
	}

	/**
	 * 
	 * @return <code>String</code>, the object's id, which is used to identify
	 *         the <code>TableElente</code> stored in the plugin's settings.
	 */
	public String getID() {
		return id;
	}

	/**
	 * 
	 * @return <code>String[]</code>, the elements of this
	 *         <code>TableElement</code>.
	 */
	public String[] getTableElements() {
		return elements;
	}

	/**
	 * Sets <code>elem</code> to column <code>col</code>.
	 * 
	 * @param elem
	 *            <code>String</code> the element that has to be set
	 * @param col
	 *            <code>int</code> the column in which the element should be
	 *            set.
	 */
	public void setElement(String elem, int col) {
		for (int i = 0; i < elements.length; i++) {
			if (i == col) {
				propertyChangeSupport.firePropertyChange("col" + i,
						elements[i], elements[i] = elem);
			}
		}
	}

	public void setElements(String[] elem) {
		if (elem.length != elements.length)
			return;
		for (int i = 0; i < elements.length; i++) {
			propertyChangeSupport.firePropertyChange("col" + i, elements[i],
					elements[i] = elem[i]);
		}
	}

	/**
	 * 
	 * @param col
	 *            <code>int</code>, the column's number
	 * @return <code>String</code> the element that is displayed in column
	 *         <code>col</code>.
	 */
	public String getElement(int col) {
		for (int i = 0; i < elements.length; i++) {
			if (i == col) {
				return elements[i];
			}
		}
		return "";
	}
}
